@@ -33,9 +33,10 @@
 #  define FCITXQTDBUSADDONS_DEPRECATED_NO_EXPORT FCITXQTDBUSADDONS_NO_EXPORT FCITXQTDBUSADDONS_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define FCITXQTDBUSADDONS_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef FCITXQTDBUSADDONS_NO_DEPRECATED
+#    define FCITXQTDBUSADDONS_NO_DEPRECATED
+#  endif
 #endif
 
-#endif
+#endif /* FCITXQTDBUSADDONS_EXPORT_H */
